@@ -278,6 +278,34 @@ class GseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def EndGameServerSessionAndProcess(self, request):
+        """This API is used to terminate the game server session and the corresponding process, which is applicable to time-limited protection and no protection.
+
+        :param request: Request instance for EndGameServerSessionAndProcess.
+        :type request: :class:`tencentcloud.gse.v20191112.models.EndGameServerSessionAndProcessRequest`
+        :rtype: :class:`tencentcloud.gse.v20191112.models.EndGameServerSessionAndProcessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("EndGameServerSessionAndProcess", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.EndGameServerSessionAndProcessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetGameServerSessionLogUrl(self, request):
         """This API is used to get the log URL of a game server session.
 
